pub struct Commands<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Commands<'a>
impl<'a> Commands<'a>
Sourcepub fn reserve_entities(&mut self, additional: u32)
pub fn reserve_entities(&mut self, additional: u32)
Reserve storage for additional number of additional entities.
Reserve happens lazily, this can be used in conjunction with spawn but not with id()
fn sys(mut cmd: Commands) {
cmd.reserve_entities(128);
for i in 0..128 {
// this is fine
cmd.spawn().insert(i);
}
}ⓘ
fn sys(mut cmd: Commands) {
cmd.reserve_entities(128);
for i in 0..128 {
// id will return an error, since the reserve has not happened yet
cmd.spawn().id().unwrap();
}
}pub fn entity(&mut self, id: EntityId) -> &mut EntityCommands
Sourcepub fn insert_id(&mut self, id: EntityId) -> &mut EntityCommands
pub fn insert_id(&mut self, id: EntityId) -> &mut EntityCommands
Take a pre-made id and insert into the world Will cause an error if the id slot is taken
pub fn spawn(&mut self) -> &mut EntityCommands
pub fn delete(&mut self, id: EntityId)
pub fn insert_resource<T: Component>(&mut self, resource: T)
pub fn remove_resource<T: Component>(&mut self)
pub fn merge_entities(&mut self, src: EntityId, dst: EntityId)