pub trait IntoSystem<'a, Param, R> {
// Required method
fn descriptor(self) -> SystemDescriptor<'a, R>;
// Provided method
fn after<'b, P, R2>(
self,
rhs: impl IntoSystem<'b, P, R2>,
) -> SystemDescriptor<'a, R>
where Self: Sized { ... }
}Required Methods
fn descriptor(self) -> SystemDescriptor<'a, R>
Provided Methods
Sourcefn after<'b, P, R2>(
self,
rhs: impl IntoSystem<'b, P, R2>,
) -> SystemDescriptor<'a, R>where
Self: Sized,
fn after<'b, P, R2>(
self,
rhs: impl IntoSystem<'b, P, R2>,
) -> SystemDescriptor<'a, R>where
Self: Sized,
Order this system after another system Note that if the systems have no conflicting queries, then they may still execute in parallel
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".